@@ -4,7 +4,7 @@
  *  \version 1
  *
  *  \date Created: 25/05/06
- *  \date Last modified: Time-stamp: <2006-05-26 14:28:09 antoine>
+ *  \date Last modified: Time-stamp: <2022-12-09 14:56:06 (antoine)>
  *
  *  \author A. Lucas
  *
@@ -45,6 +45,10 @@ extern "C"
    */
   SEXP biginteger_rbind(SEXP args) ;
 
+  /** \brief for function rbind
+   */
+  SEXP biginteger_cbind(SEXP args) ;
+
 }
 
 
@@ -52,7 +56,7 @@ extern "C"
 namespace matrixz{
 
   /** \brief C function use to transpose a matrix */
-  bigvec bigint_transpose ( bigvec & mat,int nr,int nc);
+  bigvec bigint_transpose ( bigvec & mat);
 
   /** \brief Check dimension compatibility */
   int checkDims(int  dima,int  dimb);
